Class: Aws::Notifications::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Notifications::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-notifications/client.rb,
sig/client.rbs
Overview
An API client for Notifications. To construct a client, you need to configure a :region and :credentials.
client = Aws::Notifications::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateChannelResponseSuccess, _AssociateManagedNotificationAccountContactResponseSuccess, _AssociateManagedNotificationAdditionalChannelResponseSuccess, _AssociateOrganizationalUnitResponseSuccess, _CreateEventRuleResponseSuccess, _CreateNotificationConfigurationResponseSuccess, _DeleteEventRuleResponseSuccess, _DeleteNotificationConfigurationResponseSuccess, _DeregisterNotificationHubResponseSuccess, _DisableNotificationsAccessForOrganizationResponseSuccess, _DisassociateChannelResponseSuccess, _DisassociateManagedNotificationAccountContactResponseSuccess, _DisassociateManagedNotificationAdditionalChannelResponseSuccess, _DisassociateOrganizationalUnitResponseSuccess, _EnableNotificationsAccessForOrganizationResponseSuccess, _GetEventRuleResponseSuccess, _GetManagedNotificationChildEventResponseSuccess, _GetManagedNotificationConfigurationResponseSuccess, _GetManagedNotificationEventResponseSuccess, _GetNotificationConfigurationResponseSuccess, _GetNotificationEventResponseSuccess, _GetNotificationsAccessForOrganizationResponseSuccess, _ListChannelsResponseSuccess, _ListEventRulesResponseSuccess, _ListManagedNotificationChannelAssociationsResponseSuccess, _ListManagedNotificationChildEventsResponseSuccess, _ListManagedNotificationConfigurationsResponseSuccess, _ListManagedNotificationEventsResponseSuccess, _ListMemberAccountsResponseSuccess, _ListNotificationConfigurationsResponseSuccess, _ListNotificationEventsResponseSuccess, _ListNotificationHubsResponseSuccess, _ListOrganizationalUnitsResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterNotificationHubResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEventRuleResponseSuccess, _UpdateNotificationConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_channel(params = {}) ⇒ Struct
Associates a delivery [Channel][1] with a particular
NotificationConfiguration. -
#associate_managed_notification_account_contact(params = {}) ⇒ Struct
Associates an Account Contact with a particular
ManagedNotificationConfiguration. -
#associate_managed_notification_additional_channel(params = {}) ⇒ Struct
Associates an additional Channel with a particular
ManagedNotificationConfiguration. -
#associate_organizational_unit(params = {}) ⇒ Struct
Associates an organizational unit with a notification configuration.
-
#create_event_rule(params = {}) ⇒ Types::CreateEventRuleResponse
Creates an [
EventRule][1] that is associated with a specifiedNotificationConfiguration. -
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a new
NotificationConfiguration. -
#delete_event_rule(params = {}) ⇒ Struct
Deletes an
EventRule. -
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a
NotificationConfiguration. -
#deregister_notification_hub(params = {}) ⇒ Types::DeregisterNotificationHubResponse
Deregisters a
NotificationConfigurationin the specified Region. -
#disable_notifications_access_for_organization(params = {}) ⇒ Struct
Disables service trust between User Notifications and Amazon Web Services Organizations.
-
#disassociate_channel(params = {}) ⇒ Struct
Disassociates a Channel from a specified
NotificationConfiguration. -
#disassociate_managed_notification_account_contact(params = {}) ⇒ Struct
Disassociates an Account Contact with a particular
ManagedNotificationConfiguration. -
#disassociate_managed_notification_additional_channel(params = {}) ⇒ Struct
Disassociates an additional Channel from a particular
ManagedNotificationConfiguration. -
#disassociate_organizational_unit(params = {}) ⇒ Struct
Removes the association between an organizational unit and a notification configuration.
-
#enable_notifications_access_for_organization(params = {}) ⇒ Struct
Enables service trust between User Notifications and Amazon Web Services Organizations.
-
#get_event_rule(params = {}) ⇒ Types::GetEventRuleResponse
Returns a specified
EventRule. -
#get_managed_notification_child_event(params = {}) ⇒ Types::GetManagedNotificationChildEventResponse
Returns the child event of a specific given
ManagedNotificationEvent. -
#get_managed_notification_configuration(params = {}) ⇒ Types::GetManagedNotificationConfigurationResponse
Returns a specified
ManagedNotificationConfiguration. -
#get_managed_notification_event(params = {}) ⇒ Types::GetManagedNotificationEventResponse
Returns a specified
ManagedNotificationEvent. -
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Returns a specified
NotificationConfiguration. -
#get_notification_event(params = {}) ⇒ Types::GetNotificationEventResponse
Returns a specified
NotificationEvent. -
#get_notifications_access_for_organization(params = {}) ⇒ Types::GetNotificationsAccessForOrganizationResponse
Returns the AccessStatus of Service Trust Enablement for User Notifications and Amazon Web Services Organizations.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Returns a list of Channels for a
NotificationConfiguration. -
#list_event_rules(params = {}) ⇒ Types::ListEventRulesResponse
Returns a list of
EventRulesaccording to specified filters, in reverse chronological order (newest first). -
#list_managed_notification_channel_associations(params = {}) ⇒ Types::ListManagedNotificationChannelAssociationsResponse
Returns a list of Account contacts and Channels associated with a
ManagedNotificationConfiguration, in paginated format. -
#list_managed_notification_child_events(params = {}) ⇒ Types::ListManagedNotificationChildEventsResponse
Returns a list of
ManagedNotificationChildEventsfor a specified aggregateManagedNotificationEvent, ordered by creation time in reverse chronological order (newest first). -
#list_managed_notification_configurations(params = {}) ⇒ Types::ListManagedNotificationConfigurationsResponse
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
-
#list_managed_notification_events(params = {}) ⇒ Types::ListManagedNotificationEventsResponse
Returns a list of Managed Notification Events according to specified filters, ordered by creation time in reverse chronological order (newest first).
-
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a list of member accounts associated with a notification configuration.
-
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
Returns a list of abbreviated
NotificationConfigurationsaccording to specified filters, in reverse chronological order (newest first). -
#list_notification_events(params = {}) ⇒ Types::ListNotificationEventsResponse
Returns a list of
NotificationEventsaccording to specified filters, in reverse chronological order (newest first). -
#list_notification_hubs(params = {}) ⇒ Types::ListNotificationHubsResponse
Returns a list of
NotificationHubs. -
#list_organizational_units(params = {}) ⇒ Types::ListOrganizationalUnitsResponse
Returns a list of organizational units associated with a notification configuration.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
-
#register_notification_hub(params = {}) ⇒ Types::RegisterNotificationHubResponse
Registers a
NotificationConfigurationin the specified Region. -
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
-
#update_event_rule(params = {}) ⇒ Types::UpdateEventRuleResponse
Updates an existing
EventRule. -
#update_notification_configuration(params = {}) ⇒ Types::UpdateNotificationConfigurationResponse
Updates a
NotificationConfiguration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-notifications/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2447 2448 2449 |
# File 'lib/aws-sdk-notifications/client.rb', line 2447 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2450 2451 2452 |
# File 'lib/aws-sdk-notifications/client.rb', line 2450 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_channel(params = {}) ⇒ Struct
Associates a delivery Channel with a particular
NotificationConfiguration. Supported Channels include Amazon Q
Developer in chat applications, the Console Mobile Application, and
emails (notifications-contacts).
85 |
# File 'sig/client.rbs', line 85
def associate_channel: (
|
#associate_managed_notification_account_contact(params = {}) ⇒ Struct
Associates an Account Contact with a particular
ManagedNotificationConfiguration.
95 |
# File 'sig/client.rbs', line 95
def associate_managed_notification_account_contact: (
|
#associate_managed_notification_additional_channel(params = {}) ⇒ Struct
Associates an additional Channel with a particular
ManagedNotificationConfiguration.
Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
105 |
# File 'sig/client.rbs', line 105
def associate_managed_notification_additional_channel: (
|
#associate_organizational_unit(params = {}) ⇒ Struct
Associates an organizational unit with a notification configuration.
115 |
# File 'sig/client.rbs', line 115
def associate_organizational_unit: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-notifications/client.rb', line 2420 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Notifications') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-notifications' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#create_event_rule(params = {}) ⇒ Types::CreateEventRuleResponse
Creates an EventRule that is associated with a specified
NotificationConfiguration.
128 |
# File 'sig/client.rbs', line 128
def create_event_rule: (
|
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a new NotificationConfiguration.
143 |
# File 'sig/client.rbs', line 143
def create_notification_configuration: (
|
#delete_event_rule(params = {}) ⇒ Struct
Deletes an EventRule.
155 |
# File 'sig/client.rbs', line 155
def delete_event_rule: (
|
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a NotificationConfiguration.
164 |
# File 'sig/client.rbs', line 164
def delete_notification_configuration: (
|
#deregister_notification_hub(params = {}) ⇒ Types::DeregisterNotificationHubResponse
Deregisters a NotificationConfiguration in the specified Region.
NotificationHub in the account.
NotificationEvents stored in the deregistered
NotificationConfiguration are no longer be visible. Recreating a new
NotificationConfiguration in the same Region restores access to
those NotificationEvents.
175 |
# File 'sig/client.rbs', line 175
def deregister_notification_hub: (
|
#disable_notifications_access_for_organization(params = {}) ⇒ Struct
Disables service trust between User Notifications and Amazon Web Services Organizations.
184 |
# File 'sig/client.rbs', line 184
def disable_notifications_access_for_organization: (
|
#disassociate_channel(params = {}) ⇒ Struct
Disassociates a Channel from a specified NotificationConfiguration.
Supported Channels include Amazon Q Developer in chat applications,
the Console Mobile Application, and emails (notifications-contacts).
192 |
# File 'sig/client.rbs', line 192
def disassociate_channel: (
|
#disassociate_managed_notification_account_contact(params = {}) ⇒ Struct
Disassociates an Account Contact with a particular
ManagedNotificationConfiguration.
202 |
# File 'sig/client.rbs', line 202
def disassociate_managed_notification_account_contact: (
|
#disassociate_managed_notification_additional_channel(params = {}) ⇒ Struct
Disassociates an additional Channel from a particular
ManagedNotificationConfiguration.
Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
212 |
# File 'sig/client.rbs', line 212
def disassociate_managed_notification_additional_channel: (
|
#disassociate_organizational_unit(params = {}) ⇒ Struct
Removes the association between an organizational unit and a notification configuration.
222 |
# File 'sig/client.rbs', line 222
def disassociate_organizational_unit: (
|
#enable_notifications_access_for_organization(params = {}) ⇒ Struct
Enables service trust between User Notifications and Amazon Web Services Organizations.
232 |
# File 'sig/client.rbs', line 232
def enable_notifications_access_for_organization: (
|
#get_event_rule(params = {}) ⇒ Types::GetEventRuleResponse
Returns a specified EventRule.
249 |
# File 'sig/client.rbs', line 249
def get_event_rule: (
|
#get_managed_notification_child_event(params = {}) ⇒ Types::GetManagedNotificationChildEventResponse
Returns the child event of a specific given
ManagedNotificationEvent.
262 |
# File 'sig/client.rbs', line 262
def get_managed_notification_child_event: (
|
#get_managed_notification_configuration(params = {}) ⇒ Types::GetManagedNotificationConfigurationResponse
Returns a specified ManagedNotificationConfiguration.
277 |
# File 'sig/client.rbs', line 277
def get_managed_notification_configuration: (
|
#get_managed_notification_event(params = {}) ⇒ Types::GetManagedNotificationEventResponse
Returns a specified ManagedNotificationEvent.
290 |
# File 'sig/client.rbs', line 290
def get_managed_notification_event: (
|
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Returns a specified NotificationConfiguration.
307 |
# File 'sig/client.rbs', line 307
def get_notification_configuration: (
|
#get_notification_event(params = {}) ⇒ Types::GetNotificationEventResponse
Returns a specified NotificationEvent.
User Notifications stores notifications in the individual Regions you
register as notification hubs and the Region of the source event rule.
GetNotificationEvent only returns notifications stored in the same
Region in which the action is called. User Notifications doesn't
backfill notifications to new Regions selected as notification hubs.
For this reason, we recommend that you make calls in your oldest
registered notification hub. For more information, see Notification
hubs in the Amazon Web Services User Notifications User Guide.
320 |
# File 'sig/client.rbs', line 320
def get_notification_event: (
|
#get_notifications_access_for_organization(params = {}) ⇒ Types::GetNotificationsAccessForOrganizationResponse
Returns the AccessStatus of Service Trust Enablement for User Notifications and Amazon Web Services Organizations.
331 |
# File 'sig/client.rbs', line 331
def get_notifications_access_for_organization: (
|
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Returns a list of Channels for a NotificationConfiguration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
341 |
# File 'sig/client.rbs', line 341
def list_channels: (
|
#list_event_rules(params = {}) ⇒ Types::ListEventRulesResponse
Returns a list of EventRules according to specified filters, in
reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
354 |
# File 'sig/client.rbs', line 354
def list_event_rules: (
|
#list_managed_notification_channel_associations(params = {}) ⇒ Types::ListManagedNotificationChannelAssociationsResponse
Returns a list of Account contacts and Channels associated with a
ManagedNotificationConfiguration, in paginated format.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
367 |
# File 'sig/client.rbs', line 367
def list_managed_notification_channel_associations: (
|
#list_managed_notification_child_events(params = {}) ⇒ Types::ListManagedNotificationChildEventsResponse
Returns a list of ManagedNotificationChildEvents for a specified
aggregate ManagedNotificationEvent, ordered by creation time in
reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
380 |
# File 'sig/client.rbs', line 380
def list_managed_notification_child_events: (
|
#list_managed_notification_configurations(params = {}) ⇒ Types::ListManagedNotificationConfigurationsResponse
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
398 |
# File 'sig/client.rbs', line 398
def list_managed_notification_configurations: (
|
#list_managed_notification_events(params = {}) ⇒ Types::ListManagedNotificationEventsResponse
Returns a list of Managed Notification Events according to specified filters, ordered by creation time in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
411 |
# File 'sig/client.rbs', line 411
def list_managed_notification_events: (
|
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a list of member accounts associated with a notification configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
429 |
# File 'sig/client.rbs', line 429
def list_member_accounts: (
|
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
Returns a list of abbreviated NotificationConfigurations according
to specified filters, in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
445 |
# File 'sig/client.rbs', line 445
def list_notification_configurations: (
|
#list_notification_events(params = {}) ⇒ Types::ListNotificationEventsResponse
Returns a list of NotificationEvents according to specified filters,
in reverse chronological order (newest first).
User Notifications stores notifications in the individual Regions you register as notification hubs and the Region of the source event rule. ListNotificationEvents only returns notifications stored in the same Region in which the action is called. User Notifications doesn't backfill notifications to new Regions selected as notification hubs. For this reason, we recommend that you make calls in your oldest registered notification hub. For more information, see Notification hubs in the Amazon Web Services User Notifications User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
461 |
# File 'sig/client.rbs', line 461
def list_notification_events: (
|
#list_notification_hubs(params = {}) ⇒ Types::ListNotificationHubsResponse
Returns a list of NotificationHubs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
480 |
# File 'sig/client.rbs', line 480
def list_notification_hubs: (
|
#list_organizational_units(params = {}) ⇒ Types::ListOrganizationalUnitsResponse
Returns a list of organizational units associated with a notification configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
492 |
# File 'sig/client.rbs', line 492
def list_organizational_units: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
For more information, see Tagging your Amazon Web Services resources in the Tagging Amazon Web Services Resources User Guide.
NotificationConfigurations.
504 |
# File 'sig/client.rbs', line 504
def list_tags_for_resource: (
|
#register_notification_hub(params = {}) ⇒ Types::RegisterNotificationHubResponse
Registers a NotificationConfiguration in the specified Region.
There is a maximum of one NotificationConfiguration per Region. You
can have a maximum of 3 NotificationHub resources at a time.
517 |
# File 'sig/client.rbs', line 517
def register_notification_hub: (
|
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
For more information, see Tagging your Amazon Web Services resources in the Tagging Amazon Web Services Resources User Guide.
NotificationConfigurations.
526 |
# File 'sig/client.rbs', line 526
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
For more information, see Tagging your Amazon Web Services resources in the Tagging Amazon Web Services Resources User Guide.
536 |
# File 'sig/client.rbs', line 536
def untag_resource: (
|
#update_event_rule(params = {}) ⇒ Types::UpdateEventRuleResponse
Updates an existing EventRule.
549 |
# File 'sig/client.rbs', line 549
def update_event_rule: (
|
#update_notification_configuration(params = {}) ⇒ Types::UpdateNotificationConfigurationResponse
Updates a NotificationConfiguration.
561 |
# File 'sig/client.rbs', line 561
def update_notification_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2440 2441 2442 |
# File 'lib/aws-sdk-notifications/client.rb', line 2440 def waiter_names [] end |