Class: Aws::Notifications::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Notifications::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-notifications/client.rb
Overview
An API client for Notifications. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Notifications::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_channel(params = {}) ⇒ Struct
Associates a delivery [Channel] with a particular ‘NotificationConfiguration`.
-
#associate_managed_notification_account_contact(params = {}) ⇒ Struct
Associates an Account Contact with a particular ‘ManagedNotificationConfiguration`.
-
#associate_managed_notification_additional_channel(params = {}) ⇒ Struct
Associates an additional Channel with a particular ‘ManagedNotificationConfiguration`.
-
#associate_organizational_unit(params = {}) ⇒ Struct
Associates an organizational unit with a notification configuration.
-
#create_event_rule(params = {}) ⇒ Types::CreateEventRuleResponse
Creates an [ ‘EventRule` ][1] that is associated with a specified `NotificationConfiguration`.
-
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a new ‘NotificationConfiguration`.
-
#delete_event_rule(params = {}) ⇒ Struct
Deletes an ‘EventRule`.
-
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a ‘NotificationConfiguration`.
-
#deregister_notification_hub(params = {}) ⇒ Types::DeregisterNotificationHubResponse
Deregisters a ‘NotificationConfiguration` in the specified Region.
-
#disable_notifications_access_for_organization(params = {}) ⇒ Struct
Disables service trust between User Notifications and Amazon Web Services Organizations.
-
#disassociate_channel(params = {}) ⇒ Struct
Disassociates a Channel from a specified ‘NotificationConfiguration`.
-
#disassociate_managed_notification_account_contact(params = {}) ⇒ Struct
Disassociates an Account Contact with a particular ‘ManagedNotificationConfiguration`.
-
#disassociate_managed_notification_additional_channel(params = {}) ⇒ Struct
Disassociates an additional Channel from a particular ‘ManagedNotificationConfiguration`.
-
#disassociate_organizational_unit(params = {}) ⇒ Struct
Removes the association between an organizational unit and a notification configuration.
-
#enable_notifications_access_for_organization(params = {}) ⇒ Struct
Enables service trust between User Notifications and Amazon Web Services Organizations.
-
#get_event_rule(params = {}) ⇒ Types::GetEventRuleResponse
Returns a specified ‘EventRule`.
-
#get_managed_notification_child_event(params = {}) ⇒ Types::GetManagedNotificationChildEventResponse
Returns the child event of a specific given ‘ManagedNotificationEvent`.
-
#get_managed_notification_configuration(params = {}) ⇒ Types::GetManagedNotificationConfigurationResponse
Returns a specified ‘ManagedNotificationConfiguration`.
-
#get_managed_notification_event(params = {}) ⇒ Types::GetManagedNotificationEventResponse
Returns a specified ‘ManagedNotificationEvent`.
-
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Returns a specified ‘NotificationConfiguration`.
-
#get_notification_event(params = {}) ⇒ Types::GetNotificationEventResponse
Returns a specified ‘NotificationEvent`.
-
#get_notifications_access_for_organization(params = {}) ⇒ Types::GetNotificationsAccessForOrganizationResponse
Returns the AccessStatus of Service Trust Enablement for User Notifications and Amazon Web Services Organizations.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Returns a list of Channels for a ‘NotificationConfiguration`.
-
#list_event_rules(params = {}) ⇒ Types::ListEventRulesResponse
Returns a list of ‘EventRules` according to specified filters, in reverse chronological order (newest first).
-
#list_managed_notification_channel_associations(params = {}) ⇒ Types::ListManagedNotificationChannelAssociationsResponse
Returns a list of Account contacts and Channels associated with a ‘ManagedNotificationConfiguration`, in paginated format.
-
#list_managed_notification_child_events(params = {}) ⇒ Types::ListManagedNotificationChildEventsResponse
Returns a list of ‘ManagedNotificationChildEvents` for a specified aggregate `ManagedNotificationEvent`, ordered by creation time in reverse chronological order (newest first).
-
#list_managed_notification_configurations(params = {}) ⇒ Types::ListManagedNotificationConfigurationsResponse
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
-
#list_managed_notification_events(params = {}) ⇒ Types::ListManagedNotificationEventsResponse
Returns a list of Managed Notification Events according to specified filters, ordered by creation time in reverse chronological order (newest first).
-
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a list of member accounts associated with a notification configuration.
-
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
Returns a list of abbreviated ‘NotificationConfigurations` according to specified filters, in reverse chronological order (newest first).
-
#list_notification_events(params = {}) ⇒ Types::ListNotificationEventsResponse
Returns a list of ‘NotificationEvents` according to specified filters, in reverse chronological order (newest first).
-
#list_notification_hubs(params = {}) ⇒ Types::ListNotificationHubsResponse
Returns a list of ‘NotificationHubs`.
-
#list_organizational_units(params = {}) ⇒ Types::ListOrganizationalUnitsResponse
Returns a list of organizational units associated with a notification configuration.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
-
#register_notification_hub(params = {}) ⇒ Types::RegisterNotificationHubResponse
Registers a ‘NotificationConfiguration` in the specified Region.
-
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
-
#update_event_rule(params = {}) ⇒ Types::UpdateEventRuleResponse
Updates an existing ‘EventRule`.
-
#update_notification_configuration(params = {}) ⇒ Types::UpdateNotificationConfigurationResponse
Updates a ‘NotificationConfiguration`.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-notifications/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2447 2448 2449 |
# File 'lib/aws-sdk-notifications/client.rb', line 2447 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2450 2451 2452 |
# File 'lib/aws-sdk-notifications/client.rb', line 2450 def errors_module Errors end |
Instance Method Details
#associate_channel(params = {}) ⇒ Struct
Associates a delivery [Channel] with a particular ‘NotificationConfiguration`. Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
[1]: docs.aws.amazon.com/notifications/latest/userguide/managing-delivery-channels.html
510 511 512 513 |
# File 'lib/aws-sdk-notifications/client.rb', line 510 def associate_channel(params = {}, = {}) req = build_request(:associate_channel, params) req.send_request() end |
#associate_managed_notification_account_contact(params = {}) ⇒ Struct
Associates an Account Contact with a particular ‘ManagedNotificationConfiguration`.
540 541 542 543 |
# File 'lib/aws-sdk-notifications/client.rb', line 540 def associate_managed_notification_account_contact(params = {}, = {}) req = build_request(:associate_managed_notification_account_contact, params) req.send_request() end |
#associate_managed_notification_additional_channel(params = {}) ⇒ Struct
Associates an additional Channel with a particular ‘ManagedNotificationConfiguration`.
Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
576 577 578 579 |
# File 'lib/aws-sdk-notifications/client.rb', line 576 def associate_managed_notification_additional_channel(params = {}, = {}) req = build_request(:associate_managed_notification_additional_channel, params) req.send_request() end |
#associate_organizational_unit(params = {}) ⇒ Struct
Associates an organizational unit with a notification configuration.
603 604 605 606 |
# File 'lib/aws-sdk-notifications/client.rb', line 603 def associate_organizational_unit(params = {}, = {}) req = build_request(:associate_organizational_unit, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-notifications/client.rb', line 2420 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Notifications') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-notifications' context[:gem_version] = '1.22.0' Seahorse::Client::Request.new(handlers, context) end |
#create_event_rule(params = {}) ⇒ Types::CreateEventRuleResponse
Creates an [ ‘EventRule` ][1] that is associated with a specified `NotificationConfiguration`.
[1]: docs.aws.amazon.com/notifications/latest/userguide/glossary.html
688 689 690 691 |
# File 'lib/aws-sdk-notifications/client.rb', line 688 def create_event_rule(params = {}, = {}) req = build_request(:create_event_rule, params) req.send_request() end |
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a new ‘NotificationConfiguration`.
752 753 754 755 |
# File 'lib/aws-sdk-notifications/client.rb', line 752 def create_notification_configuration(params = {}, = {}) req = build_request(:create_notification_configuration, params) req.send_request() end |
#delete_event_rule(params = {}) ⇒ Struct
Deletes an ‘EventRule`.
774 775 776 777 |
# File 'lib/aws-sdk-notifications/client.rb', line 774 def delete_event_rule(params = {}, = {}) req = build_request(:delete_event_rule, params) req.send_request() end |
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a ‘NotificationConfiguration`.
797 798 799 800 |
# File 'lib/aws-sdk-notifications/client.rb', line 797 def delete_notification_configuration(params = {}, = {}) req = build_request(:delete_notification_configuration, params) req.send_request() end |
#deregister_notification_hub(params = {}) ⇒ Types::DeregisterNotificationHubResponse
Deregisters a ‘NotificationConfiguration` in the specified Region.
<note markdown=“1”> You can’t deregister the last ‘NotificationHub` in the account. `NotificationEvents` stored in the deregistered `NotificationConfiguration` are no longer be visible. Recreating a new `NotificationConfiguration` in the same Region restores access to those `NotificationEvents`.
</note>
836 837 838 839 |
# File 'lib/aws-sdk-notifications/client.rb', line 836 def deregister_notification_hub(params = {}, = {}) req = build_request(:deregister_notification_hub, params) req.send_request() end |
#disable_notifications_access_for_organization(params = {}) ⇒ Struct
Disables service trust between User Notifications and Amazon Web Services Organizations.
850 851 852 853 |
# File 'lib/aws-sdk-notifications/client.rb', line 850 def disable_notifications_access_for_organization(params = {}, = {}) req = build_request(:disable_notifications_access_for_organization, params) req.send_request() end |
#disassociate_channel(params = {}) ⇒ Struct
Disassociates a Channel from a specified ‘NotificationConfiguration`. Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
878 879 880 881 |
# File 'lib/aws-sdk-notifications/client.rb', line 878 def disassociate_channel(params = {}, = {}) req = build_request(:disassociate_channel, params) req.send_request() end |
#disassociate_managed_notification_account_contact(params = {}) ⇒ Struct
Disassociates an Account Contact with a particular ‘ManagedNotificationConfiguration`.
908 909 910 911 |
# File 'lib/aws-sdk-notifications/client.rb', line 908 def disassociate_managed_notification_account_contact(params = {}, = {}) req = build_request(:disassociate_managed_notification_account_contact, params) req.send_request() end |
#disassociate_managed_notification_additional_channel(params = {}) ⇒ Struct
Disassociates an additional Channel from a particular ‘ManagedNotificationConfiguration`.
Supported Channels include Amazon Q Developer in chat applications, the Console Mobile Application, and emails (notifications-contacts).
940 941 942 943 |
# File 'lib/aws-sdk-notifications/client.rb', line 940 def disassociate_managed_notification_additional_channel(params = {}, = {}) req = build_request(:disassociate_managed_notification_additional_channel, params) req.send_request() end |
#disassociate_organizational_unit(params = {}) ⇒ Struct
Removes the association between an organizational unit and a notification configuration.
968 969 970 971 |
# File 'lib/aws-sdk-notifications/client.rb', line 968 def disassociate_organizational_unit(params = {}, = {}) req = build_request(:disassociate_organizational_unit, params) req.send_request() end |
#enable_notifications_access_for_organization(params = {}) ⇒ Struct
Enables service trust between User Notifications and Amazon Web Services Organizations.
982 983 984 985 |
# File 'lib/aws-sdk-notifications/client.rb', line 982 def enable_notifications_access_for_organization(params = {}, = {}) req = build_request(:enable_notifications_access_for_organization, params) req.send_request() end |
#get_event_rule(params = {}) ⇒ Types::GetEventRuleResponse
Returns a specified ‘EventRule`.
1030 1031 1032 1033 |
# File 'lib/aws-sdk-notifications/client.rb', line 1030 def get_event_rule(params = {}, = {}) req = build_request(:get_event_rule, params) req.send_request() end |
#get_managed_notification_child_event(params = {}) ⇒ Types::GetManagedNotificationChildEventResponse
Returns the child event of a specific given ‘ManagedNotificationEvent`.
1096 1097 1098 1099 |
# File 'lib/aws-sdk-notifications/client.rb', line 1096 def get_managed_notification_child_event(params = {}, = {}) req = build_request(:get_managed_notification_child_event, params) req.send_request() end |
#get_managed_notification_configuration(params = {}) ⇒ Types::GetManagedNotificationConfigurationResponse
Returns a specified ‘ManagedNotificationConfiguration`.
1133 1134 1135 1136 |
# File 'lib/aws-sdk-notifications/client.rb', line 1133 def get_managed_notification_configuration(params = {}, = {}) req = build_request(:get_managed_notification_configuration, params) req.send_request() end |
#get_managed_notification_event(params = {}) ⇒ Types::GetManagedNotificationEventResponse
Returns a specified ‘ManagedNotificationEvent`.
1215 1216 1217 1218 |
# File 'lib/aws-sdk-notifications/client.rb', line 1215 def get_managed_notification_event(params = {}, = {}) req = build_request(:get_managed_notification_event, params) req.send_request() end |
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Returns a specified ‘NotificationConfiguration`.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-notifications/client.rb', line 1256 def get_notification_configuration(params = {}, = {}) req = build_request(:get_notification_configuration, params) req.send_request() end |
#get_notification_event(params = {}) ⇒ Types::GetNotificationEventResponse
Returns a specified ‘NotificationEvent`.
User Notifications stores notifications in the individual Regions you register as notification hubs and the Region of the source event rule. ‘GetNotificationEvent` only returns notifications stored in the same Region in which the action is called. User Notifications doesn’t backfill notifications to new Regions selected as notification hubs. For this reason, we recommend that you make calls in your oldest registered notification hub. For more information, see [Notification hubs] in the *Amazon Web Services User Notifications User Guide*.
[1]: docs.aws.amazon.com/notifications/latest/userguide/notification-hubs.html
1369 1370 1371 1372 |
# File 'lib/aws-sdk-notifications/client.rb', line 1369 def get_notification_event(params = {}, = {}) req = build_request(:get_notification_event, params) req.send_request() end |
#get_notifications_access_for_organization(params = {}) ⇒ Types::GetNotificationsAccessForOrganizationResponse
Returns the AccessStatus of Service Trust Enablement for User Notifications and Amazon Web Services Organizations.
1389 1390 1391 1392 |
# File 'lib/aws-sdk-notifications/client.rb', line 1389 def get_notifications_access_for_organization(params = {}, = {}) req = build_request(:get_notifications_access_for_organization, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Returns a list of Channels for a ‘NotificationConfiguration`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-notifications/client.rb', line 1433 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_event_rules(params = {}) ⇒ Types::ListEventRulesResponse
Returns a list of ‘EventRules` according to specified filters, in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1489 1490 1491 1492 |
# File 'lib/aws-sdk-notifications/client.rb', line 1489 def list_event_rules(params = {}, = {}) req = build_request(:list_event_rules, params) req.send_request() end |
#list_managed_notification_channel_associations(params = {}) ⇒ Types::ListManagedNotificationChannelAssociationsResponse
Returns a list of Account contacts and Channels associated with a ‘ManagedNotificationConfiguration`, in paginated format.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-notifications/client.rb', line 1536 def list_managed_notification_channel_associations(params = {}, = {}) req = build_request(:list_managed_notification_channel_associations, params) req.send_request() end |
#list_managed_notification_child_events(params = {}) ⇒ Types::ListManagedNotificationChildEventsResponse
Returns a list of ‘ManagedNotificationChildEvents` for a specified aggregate `ManagedNotificationEvent`, ordered by creation time in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1620 1621 1622 1623 |
# File 'lib/aws-sdk-notifications/client.rb', line 1620 def list_managed_notification_child_events(params = {}, = {}) req = build_request(:list_managed_notification_child_events, params) req.send_request() end |
#list_managed_notification_configurations(params = {}) ⇒ Types::ListManagedNotificationConfigurationsResponse
Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1669 1670 1671 1672 |
# File 'lib/aws-sdk-notifications/client.rb', line 1669 def list_managed_notification_configurations(params = {}, = {}) req = build_request(:list_managed_notification_configurations, params) req.send_request() end |
#list_managed_notification_events(params = {}) ⇒ Types::ListManagedNotificationEventsResponse
Returns a list of Managed Notification Events according to specified filters, ordered by creation time in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1774 1775 1776 1777 |
# File 'lib/aws-sdk-notifications/client.rb', line 1774 def list_managed_notification_events(params = {}, = {}) req = build_request(:list_managed_notification_events, params) req.send_request() end |
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a list of member accounts associated with a notification configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1835 1836 1837 1838 |
# File 'lib/aws-sdk-notifications/client.rb', line 1835 def list_member_accounts(params = {}, = {}) req = build_request(:list_member_accounts, params) req.send_request() end |
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
Returns a list of abbreviated ‘NotificationConfigurations` according to specified filters, in reverse chronological order (newest first).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1932 1933 1934 1935 |
# File 'lib/aws-sdk-notifications/client.rb', line 1932 def list_notification_configurations(params = {}, = {}) req = build_request(:list_notification_configurations, params) req.send_request() end |
#list_notification_events(params = {}) ⇒ Types::ListNotificationEventsResponse
Returns a list of ‘NotificationEvents` according to specified filters, in reverse chronological order (newest first).
User Notifications stores notifications in the individual Regions you register as notification hubs and the Region of the source event rule. ListNotificationEvents only returns notifications stored in the same Region in which the action is called. User Notifications doesn’t backfill notifications to new Regions selected as notification hubs. For this reason, we recommend that you make calls in your oldest registered notification hub. For more information, see [Notification hubs] in the *Amazon Web Services User Notifications User Guide*.
[1]: docs.aws.amazon.com/notifications/latest/userguide/notification-hubs.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2060 2061 2062 2063 |
# File 'lib/aws-sdk-notifications/client.rb', line 2060 def list_notification_events(params = {}, = {}) req = build_request(:list_notification_events, params) req.send_request() end |
#list_notification_hubs(params = {}) ⇒ Types::ListNotificationHubsResponse
Returns a list of ‘NotificationHubs`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2102 2103 2104 2105 |
# File 'lib/aws-sdk-notifications/client.rb', line 2102 def list_notification_hubs(params = {}, = {}) req = build_request(:list_notification_hubs, params) req.send_request() end |
#list_organizational_units(params = {}) ⇒ Types::ListOrganizationalUnitsResponse
Returns a list of organizational units associated with a notification configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-notifications/client.rb', line 2147 def list_organizational_units(params = {}, = {}) req = build_request(:list_organizational_units, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
For more information, see [Tagging your Amazon Web Services resources] in the *Tagging Amazon Web Services Resources User Guide*.
<note markdown=“1”> This is only supported for ‘NotificationConfigurations`.
</note>
[1]: docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html
2188 2189 2190 2191 |
# File 'lib/aws-sdk-notifications/client.rb', line 2188 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#register_notification_hub(params = {}) ⇒ Types::RegisterNotificationHubResponse
Registers a ‘NotificationConfiguration` in the specified Region.
There is a maximum of one ‘NotificationConfiguration` per Region. You can have a maximum of 3 `NotificationHub` resources at a time.
2226 2227 2228 2229 |
# File 'lib/aws-sdk-notifications/client.rb', line 2226 def register_notification_hub(params = {}, = {}) req = build_request(:register_notification_hub, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
For more information, see [Tagging your Amazon Web Services resources] in the *Tagging Amazon Web Services Resources User Guide*.
<note markdown=“1”> This is only supported for ‘NotificationConfigurations`.
</note>
[1]: docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html
2267 2268 2269 2270 |
# File 'lib/aws-sdk-notifications/client.rb', line 2267 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
For more information, see [Tagging your Amazon Web Services resources] in the *Tagging Amazon Web Services Resources User Guide*.
[1]: docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html
2301 2302 2303 2304 |
# File 'lib/aws-sdk-notifications/client.rb', line 2301 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_event_rule(params = {}) ⇒ Types::UpdateEventRuleResponse
Updates an existing ‘EventRule`.
2352 2353 2354 2355 |
# File 'lib/aws-sdk-notifications/client.rb', line 2352 def update_event_rule(params = {}, = {}) req = build_request(:update_event_rule, params) req.send_request() end |
#update_notification_configuration(params = {}) ⇒ Types::UpdateNotificationConfigurationResponse
Updates a ‘NotificationConfiguration`.
2411 2412 2413 2414 |
# File 'lib/aws-sdk-notifications/client.rb', line 2411 def update_notification_configuration(params = {}, = {}) req = build_request(:update_notification_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2440 2441 2442 |
# File 'lib/aws-sdk-notifications/client.rb', line 2440 def waiter_names [] end |